@@ -87,41 +87,35 @@ void SystemLoadViewer::reconnectSources()
 
     sys_mon->connectSource("mem/swap/used", this, m_updateInterval);
     sys_mon->connectSource("mem/swap/free", this, m_updateInterval);
+    
+    //Watch this cpu source here, as it doesn't need disconnection when the other cpu ones do.
+    sys_mon->connectSource("system/cores", this, m_updateInterval);
 }
 
 void SystemLoadViewer::reconnectCPUSources()
 {
-    m_numCPUs = sys_mon->query("system/cores")["value"].toUInt();
-    
-    if (!m_showMultiCPU) {
+    sys_mon->connectSource("cpu/system/user", this, m_updateInterval);
+    sys_mon->connectSource("cpu/system/sys", this, m_updateInterval);
+    sys_mon->connectSource("cpu/system/nice", this, m_updateInterval);
+    sys_mon->connectSource("cpu/system/wait", this, m_updateInterval);
+    sys_mon->connectSource("cpu/system/AverageClock", this, m_updateInterval);
 
-        sys_mon->connectSource("cpu/system/user", this, m_updateInterval);
-        sys_mon->connectSource("cpu/system/sys", this, m_updateInterval);
-        sys_mon->connectSource("cpu/system/nice", this, m_updateInterval);
-        sys_mon->connectSource("cpu/system/wait", this, m_updateInterval);
-        sys_mon->connectSource("cpu/system/idle", this, m_updateInterval);
-        sys_mon->connectSource("cpu/system/AverageClock", this, m_updateInterval);
-        
-    } else {
+    if (m_numCPUs == 0) {
+        //If we have zero, either the sources doesn't exist or theres a problem.
+        return ;
+    }
 
-        if (m_numCPUs == 0) {
-            //If we have zero, either the sources doesn't exist or theres a problem.
-            return ;
-        }
+    m_cpuInfo.resize(m_numCPUs);
 
-        m_cpuInfo.resize(m_numCPUs);
+    for (uint i = 0; i < m_numCPUs; ++i) {
 
-        for (uint i = 0; i < m_numCPUs; ++i) {
+        sys_mon->connectSource(QString("cpu/cpu%1/user").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/sys").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/nice").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/wait").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/clock").arg(i), this, m_updateInterval);
+        m_cpuInfo[i].clockValid = false;
 
-            sys_mon->connectSource(QString("cpu/cpu%1/user").arg(i), this, m_updateInterval);
-            sys_mon->connectSource(QString("cpu/cpu%1/sys").arg(i), this, m_updateInterval);
-            sys_mon->connectSource(QString("cpu/cpu%1/nice").arg(i), this, m_updateInterval);
-            sys_mon->connectSource(QString("cpu/cpu%1/wait").arg(i), this, m_updateInterval);
-            sys_mon->connectSource(QString("cpu/cpu%1/idle").arg(i), this, m_updateInterval);
-            sys_mon->connectSource(QString("cpu/cpu%1/clock").arg(i), this, m_updateInterval);
-            m_cpuInfo[i].clockValid = false;
-
-        }
     }
 }
 
@@ -137,36 +131,41 @@ void SystemLoadViewer::disconnectSources()
 
     sys_mon->disconnectSource("mem/swap/used", this);
     sys_mon->disconnectSource("mem/swap/free", this);
+    
+    for (uint i = 0; i < m_numCPUs; ++i) {
+
+        sys_mon->connectSource(QString("cpu/cpu%1/user").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/sys").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/nice").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/wait").arg(i), this, m_updateInterval);
+        sys_mon->connectSource(QString("cpu/cpu%1/clock").arg(i), this, m_updateInterval);
+        m_cpuInfo[i].clockValid = false;
+
+    }
+    
+    //Loose this cpu source here, as it doesn't need disconnection when the other cpu ones do.
+    sys_mon->connectSource("system/cores", this);
 }
 
 void SystemLoadViewer::disconnectCPUSources()
 {
-#if 0
-    if (!m_showMultiCPU) {
+    sys_mon->disconnectSource("cpu/system/user", this);
+    sys_mon->disconnectSource("cpu/system/sys", this);
+    sys_mon->disconnectSource("cpu/system/nice", this);
+    sys_mon->disconnectSource("cpu/system/wait", this);
+    sys_mon->disconnectSource("cpu/system/AverageClock", this);
+    m_systemCpuInfo.clockValid = false;
 
-        sys_mon->disconnectSource("cpu/system/user", this);
-        sys_mon->disconnectSource("cpu/system/sys", this);
-        sys_mon->disconnectSource("cpu/system/nice", this);
-        sys_mon->disconnectSource("cpu/system/wait", this);
-        sys_mon->disconnectSource("cpu/system/idle", this);
-        sys_mon->disconnectSource("cpu/system/AverageClock", this);
-        m_cpuInfo[0].clockValid = false;
+    for (uint i = 0; i < m_numCPUs; ++i) {
 
-    } else {
+        sys_mon->disconnectSource(QString("cpu/cpu%1/user").arg(i), this);
+        sys_mon->disconnectSource(QString("cpu/cpu%1/sys").arg(i), this);
+        sys_mon->disconnectSource(QString("cpu/cpu%1/nice").arg(i), this);
+        sys_mon->disconnectSource(QString("cpu/cpu%1/wait").arg(i), this);
+        sys_mon->disconnectSource(QString("cpu/cpu%1/clock").arg(i), this);
+        m_cpuInfo[i].clockValid = false;
 
-        for (uint i = 0; i < m_numCPUs; ++i) {
-
-            sys_mon->disconnectSource(QString("cpu/cpu%1/user").arg(i), this);
-            sys_mon->disconnectSource(QString("cpu/cpu%1/sys").arg(i), this);
-            sys_mon->disconnectSource(QString("cpu/cpu%1/nice").arg(i), this);
-            sys_mon->disconnectSource(QString("cpu/cpu%1/wait").arg(i), this);
-            sys_mon->disconnectSource(QString("cpu/cpu%1/idle").arg(i), this);
-            sys_mon->disconnectSource(QString("cpu/cpu%1/clock").arg(i), this);
-            m_cpuInfo[i].clockValid = false;
-
-        }
     }
-#endif
 }
 
 void SystemLoadViewer::sourcesAdded(const QString &source)
@@ -180,7 +179,7 @@ void SystemLoadViewer::sourcesAdded(const QString &source)
 
         if (source.endsWith(QLatin1String("/user")) || source.endsWith(QLatin1String("/sys")) ||
             source.endsWith(QLatin1String("/nice")) || source.endsWith(QLatin1String("/wait")) ||
-            source.endsWith(QLatin1String("/idle")) || source.endsWith(QLatin1String("/AverageClock")))
+            source.endsWith(QLatin1String("/AverageClock")))
         {
             sys_mon->connectSource(source, this, m_updateInterval);
         }
@@ -189,7 +188,7 @@ void SystemLoadViewer::sourcesAdded(const QString &source)
 
         if (source.endsWith(QLatin1String("/user")) || source.endsWith(QLatin1String("/sys")) ||
             source.endsWith(QLatin1String("/nice")) || source.endsWith(QLatin1String("/wait")) ||
-            source.endsWith(QLatin1String("/idle")) || source.endsWith(QLatin1String("/clock")) )
+            source.endsWith(QLatin1String("/clock")) )
         {
             sys_mon->connectSource(source, this, m_updateInterval);
         }
@@ -419,25 +418,26 @@ void SystemLoadViewer::dataUpdated(const QString& source, const Plasma::DataEngi
 {
     //kDebug() << source << "=" << data["value"].toString();
     if (source == "system/cores") {
-        if (data["value"].toUInt() != m_numCPUs) {
+        uint newNumCPUs = data["value"].toUInt();
+        if (newNumCPUs != m_numCPUs) {
             disconnectCPUSources();
+            m_numCPUs = newNumCPUs; //Make the switch here so that we lose all previous connections, otherwise if
+                                    //we lose cores we will retain unwanted source connections.
             reconnectCPUSources();
             updateConstraints(Plasma::SizeConstraint);
         }
     } else if (!m_showMultiCPU && source.startsWith(QLatin1String("cpu/system/"))) {
         if (source.endsWith(QLatin1String("/user"))) {
-            m_cpuInfo[0].user = (data["value"].toString().toDouble()) / 100;
+            m_systemCpuInfo.user = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/sys"))) {
-            m_cpuInfo[0].sys = (data["value"].toString().toDouble()) / 100;
+            m_systemCpuInfo.sys = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/nice"))) {
-            m_cpuInfo[0].nice = (data["value"].toString().toDouble()) / 100;
+            m_systemCpuInfo.nice = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/wait"))) {
-            m_cpuInfo[0].disk = (data["value"].toString().toDouble()) / 100;
-        } else if (source.endsWith(QLatin1String("/idle"))) {
-            m_cpuInfo[0].idle = (data["value"].toString().toDouble()) / 100;
+            m_systemCpuInfo.disk = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/AverageClock"))) {
-            m_cpuInfo[0].clockValid = true;
-            m_cpuInfo[0].clock = (data["value"].toString().toDouble());
+            m_systemCpuInfo.clockValid = true;
+            m_systemCpuInfo.clock = (data["value"].toString().toDouble());
         }
     } else if (m_showMultiCPU && source.startsWith(QLatin1String("cpu/cpu")) && (m_numCPUs != 0)) {
         int cpu = source.split('/')[1].mid(3).toInt();
@@ -456,8 +456,6 @@ void SystemLoadViewer::dataUpdated(const QString& source, const Plasma::DataEngi
             m_cpuInfo[cpu].nice = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/wait"))) {
             m_cpuInfo[cpu].disk = (data["value"].toString().toDouble()) / 100;
-        } else if (source.endsWith(QLatin1String("/idle"))) {
-            m_cpuInfo[cpu].idle = (data["value"].toString().toDouble()) / 100;
         } else if (source.endsWith(QLatin1String("/clock"))) {
             m_cpuInfo[cpu].clockValid = true;
             m_cpuInfo[cpu].clock = (data["value"].toString().toDouble());
@@ -469,15 +467,20 @@ void SystemLoadViewer::dataUpdated(const QString& source, const Plasma::DataEngi
             m_swapfree = data["value"].toDouble() / 100;
         }
 
-        m_swaptotal = qMax(1.0, m_swapfree + m_swapused);
-        if (m_swapAvailable && m_swapfree + m_swapused == 0) {
-            m_swapAvailable = false;
-            updateConstraints(Plasma::SizeConstraint);
-        } else if (!m_swapAvailable) {
-            m_swapAvailable = true;
-            updateConstraints(Plasma::SizeConstraint);
+        m_swaptotal = m_swapfree + m_swapused;
+        if(qFuzzyCompare(m_swaptotal+1, 1.0)) {
+            if(m_swapAvailable) {
+                m_swapAvailable = false;
+                updateConstraints(Plasma::SizeConstraint);
+            }
+        }else {
+            if(!m_swapAvailable) {
+                m_swapAvailable = true;
+                updateConstraints(Plasma::SizeConstraint);
+            }
         }
 
+        m_swaptotal = qMax(0.1, m_swaptotal); //Make sure we never have a zero value for swap total, avoiding division by 0 errors.
     } else if (source.startsWith(QLatin1String("mem/physical/"))) {
         if (source.endsWith(QLatin1String("/application"))) {
             m_ramapps = data["value"].toDouble();
@@ -516,14 +519,14 @@ static inline void drawSection(QPainter* p, const QColor& color, const QRectF& r
     }
 }
 
-void SystemLoadViewer::paintCPUUsage(QPainter *p, const QStyleOptionGraphicsItem *option, const QRect& contentsRect, const cpuInfo &cpu)
+void SystemLoadViewer::paintCPUUsage(QPainter *p, const QStyleOptionGraphicsItem *option, const QRect& contentsRect, const CpuInfo &cpu)
 {
     Q_UNUSED(option)
 
     p->save();
     p->scale(contentsRect.width(), 1.0);
 
-    qreal height = contentsRect.height() * (1 - (cpu.nice + cpu.user + cpu.disk + cpu.sys));//cpu.idle;
+    qreal height = contentsRect.height() * (1 - (cpu.nice + cpu.user + cpu.disk + cpu.sys)); //Compute idle from components to avoid race conditions.
     drawSection(p, m_freeResourceColor, QRectF(0, contentsRect.top(), 1.0, height));
 
     height = contentsRect.height() * cpu.nice;
@@ -601,8 +604,13 @@ void SystemLoadViewer::paintInterface(QPainter *p, const QStyleOptionGraphicsIte
     p->translate(rotatedContentsRect.left(), 0);
     rotatedContentsRect.moveLeft(0.0);
 
-    for (int i = 0; i < cpuCount(); ++i) {
-        paintCPUUsage(p, option, rotatedContentsRect, m_cpuInfo[i]);
+    if(m_showMultiCPU){
+        for (int i = 0; i < cpuCount(); ++i) {
+            paintCPUUsage(p, option, rotatedContentsRect, m_cpuInfo[i]);
+            p->translate(barWidth, 0);
+        }
+    } else {
+        paintCPUUsage(p, option, rotatedContentsRect, m_systemCpuInfo);
         p->translate(barWidth, 0);
     }
 
@@ -652,13 +660,13 @@ void SystemLoadViewer::toolTipAboutToShow()
             }
         }
     } else {
-        cpuUsage = qRound((m_cpuInfo[0].nice + m_cpuInfo[0].user + m_cpuInfo[0].disk + m_cpuInfo[0].sys) * 100);
-        if (m_cpuInfo[0].clockValid) {
+        cpuUsage = qRound((m_systemCpuInfo.nice + m_systemCpuInfo.user + m_systemCpuInfo.disk + m_systemCpuInfo.sys) * 100);
+        if (m_systemCpuInfo.clockValid) {
             if (m_numCPUs >1) {
-                content += i18n("CPU Usage: %1% at %2 MHz/CPU<br />", cpuUsage, m_cpuInfo[0].clock);
+                content += i18n("CPU Usage: %1% at %2 MHz/CPU<br />", cpuUsage, m_systemCpuInfo.clock);
             }
             else {
-                content += i18n("CPU Usage: %1% at %2 MHz<br />", cpuUsage, m_cpuInfo[0].clock);
+                content += i18n("CPU Usage: %1% at %2 MHz<br />", cpuUsage, m_systemCpuInfo.clock);
             }
         }
         else {
