@@ -28,6 +28,8 @@
 #include <kstandarddirs.h>
 #include <KUrl>
 
+const int CachedProvider::CACHE_DEFAULT = 20;
+
 static QString identifierToPath( const QString &identifier )
 {
     const QString dataDir = KStandardDirs::locateLocal( "data", QLatin1String( "plasma_engine_comic/" ));
@@ -176,7 +178,7 @@ bool CachedProvider::storeInCache( const QString &identifier, const QImage &comi
 
         const int limit = CachedProvider::maxComicLimit();
         //limit is on
-        if ( limit > - 1) {
+        if ( limit > 0 ) {
             kDebug() << QLatin1String( "MaxComicLimit on." );
             int comicsToRemove = comics.count() - limit;
             QStringList::iterator it = comics.begin();
@@ -227,13 +229,15 @@ bool CachedProvider::isTopToBottom() const
 int CachedProvider::maxComicLimit()
 {
     QSettings settings( identifierToPath( QLatin1String( "comic_settings.conf" ) ), QSettings::IniFormat );
-    bool worked;
-    const int maxComics = settings.value( QLatin1String( "maxComics" ), -1 ).toInt( &worked );
-    return ( worked ? maxComics : - 1 );
+    return  qMax( settings.value( QLatin1String( "maxComics" ), CACHE_DEFAULT ).toInt(), 0 );//old value was -1, thus use qMax
 }
 
 void CachedProvider::setMaxComicLimit( int limit )
 {
+    if ( limit < 0 ) {
+        kDebug() << "Wrong limit, setting to default.";
+        limit = CACHE_DEFAULT;
+    }
     QSettings settings( identifierToPath( QLatin1String( "comic_settings.conf" ) ), QSettings::IniFormat );
     settings.setValue( QLatin1String( "maxComics" ), limit );
 }
