@@ -6,7 +6,7 @@
 
 #if defined _WIN32 || defined _WIN64
 #ifndef PLASMA_COMIC_EXPORT
-# ifdef MAKE_PLASMACOMICCORE_LIB
+# ifdef MAKE_PLASMACOMICPROVIDERCORE_LIB
 #  define PLASMA_COMIC_EXPORT KDE_EXPORT
 # else
 #  define PLASMA_COMIC_EXPORT KDE_IMPORT
