@@ -65,8 +65,9 @@ MarbleWallpaper::~MarbleWallpaper()
 
 void MarbleWallpaper::init(const KConfigGroup &config)
 {
-    qreal home_lon, home_lat;
-    int home_zoom;
+    qreal home_lon = 0;
+    qreal home_lat = 0;
+    int home_zoom = 0;
 
     // Only on first start, otherwise opening the config dialog lets us
     // lose the current position
@@ -75,11 +76,12 @@ void MarbleWallpaper::init(const KConfigGroup &config)
 
         // Get default position from marble to initialize on first startup (empty config)
         m_map->model()->home(home_lon, home_lat, home_zoom);
+        m_map->model()->setClockDateTime( QDateTime::currentDateTime().toUTC() );
 
         // These settings apply to Marble's "satellite" view mostly, e.g. make it beautiful
         m_map->setShowClouds(true);
-        m_map->sunLocator()->setCitylights(false);
-        m_map->sunLocator()->setShow(true);
+        m_map->model()->sunLocator()->setCitylights(false);
+        m_map->model()->sunLocator()->setShow(true);
 
         // Disable all render plugins (scale bar, compass, etc.) except the "stars" plugin
         foreach (RenderPlugin *item, m_map->renderPlugins()) {
@@ -111,9 +113,11 @@ void MarbleWallpaper::init(const KConfigGroup &config)
     m_map->setShowCities(m_showPlacemarks);
     m_map->setShowOtherPlaces(m_showPlacemarks);
     m_map->setShowPlaces(m_showPlacemarks);
+    m_map->setShowTerrain(m_showPlacemarks);
 
     if (!isInitialized()) {
-        m_map->zoomView(m_zoom);
+        qreal radius = pow(M_E, (m_zoom / 200.0));
+        m_map->setRadius(radius);
         m_map->centerOn(m_positionLon, m_positionLat);
     }
     updateGlobe();
@@ -208,8 +212,9 @@ void MarbleWallpaper::wheelEvent(QGraphicsSceneWheelEvent *event)
 {
     if (m_movement == Interactive) {
         event->accept();
-        m_map->zoomViewBy(event->delta() > 0 ? 10 : -10);
-        m_zoom = m_map->zoom();
+        m_zoom = qMax(qreal(0), m_zoom + (event->delta() > 0 ? 10 : -10));
+        qreal radius = pow(M_E, (m_zoom / 200.0));
+        m_map->setRadius(radius);
 
         emit update(boundingRect());
     }
@@ -290,12 +295,12 @@ void MarbleWallpaper::updateGlobe()
     m_timer->start();
 
     if (m_movement == FollowSun) {
-        m_map->sunLocator()->update();
-        if (m_map->sunLocator()->getLon() == m_map->centerLongitude()) {
+        m_map->model()->sunLocator()->update();
+        if (m_map->model()->sunLocator()->getLon() == m_map->centerLongitude()) {
             return;
         }
-        m_positionLon = m_map->sunLocator()->getLon();
-        m_positionLat = m_map->sunLocator()->getLat();
+        m_positionLon = m_map->model()->sunLocator()->getLon();
+        m_positionLat = m_map->model()->sunLocator()->getLat();
         m_map->centerOn(m_positionLon, m_positionLat);
     } else if (m_movement == Rotate) {
         m_map->rotateBy(m_rotationLon * m_rotationTimeout / 1000,
